==> dart_apitool-0.5.1.tar.gz: test/integration_tests/analyze/bloc_test.dart <==
import 'package:dart_apitool/api_tool.dart';
import 'package:test/test.dart';

void main() {
  group('bloc get analyzed correctly', () {
    late PackageApi packageApi;
    setUpAll(() async {
      final packageName = 'bloc';
      final packageVersion = '8.1.0';
      //download from pub
      final packageDirectory = await PubInteraction.installPackageToCache(
        packageName,
        packageVersion,
      );

      final analyzer = PackageApiAnalyzer(packagePath: packageDirectory);
      packageApi = await analyzer.analyze();
    });
    test('Bloc class is available', () {
      final blocClass = packageApi.classDeclarations
          .singleWhere((element) => element.name == 'Bloc');

      expect(blocClass.name, 'Bloc');
      expect(blocClass.entryPoints, contains('bloc.dart'));
      final stateField = blocClass.fieldDeclarations
          .singleWhere((element) => element.name == 'state');
      expect(stateField.name, 'state');
      expect(stateField.typeName, 'State');
    });
    test('Transition class is available', () {
      final transitionClass = packageApi.classDeclarations
          .singleWhere((element) => element.name == 'Transition');

      expect(transitionClass.name, 'Transition');
      expect(transitionClass.entryPoints, contains('bloc.dart'));
      final eventField = transitionClass.fieldDeclarations
          .singleWhere((element) => element.name == 'event');
      expect(eventField.name, 'event');
      expect(eventField.typeName, 'Event');
    });
    test('EventHandler typedef is available', () {
      final eventHandlerTypedef = packageApi.typeAliasDeclarations
          .singleWhere((element) => element.name == 'EventHandler');

      expect(eventHandlerTypedef.name, 'EventHandler');
      expect(eventHandlerTypedef.aliasedTypeName,
          'FutureOr<void> Function(Event, Emitter<State>)');
    });
  });
}

==> dart_apitool-0.6.0.tar.gz: test/integration_tests/analyze/bloc_test.dart <==
import 'package:dart_apitool/api_tool.dart';
import 'package:test/test.dart';

import '../helper/integration_test_helper.dart';

void main() {
  group('bloc get analyzed correctly', () {
    final packageName = 'bloc';
    final packageVersion = '8.1.0';
    final retriever = PackageApiRetriever(packageName, packageVersion);
    late PackageApi packageApi;

    setUpAll(() async {
      packageApi = await retriever.retrieve();
    });

    test('Bloc class is available', () {
      final blocClass = packageApi.classDeclarations
          .singleWhere((element) => element.name == 'Bloc');

      expect(blocClass.name, 'Bloc');
      expect(blocClass.entryPoints, contains('bloc.dart'));
      final stateField = blocClass.fieldDeclarations
          .singleWhere((element) => element.name == 'state');
      expect(stateField.name, 'state');
      expect(stateField.typeName, 'State');
    });
    test('Transition class is available', () {
      final transitionClass = packageApi.classDeclarations
          .singleWhere((element) => element.name == 'Transition');

      expect(transitionClass.name, 'Transition');
      expect(transitionClass.entryPoints, contains('bloc.dart'));
      final eventField = transitionClass.fieldDeclarations
          .singleWhere((element) => element.name == 'event');
      expect(eventField.name, 'event');
      expect(eventField.typeName, 'Event');
    });
    test('EventHandler typedef is available', () {
      final eventHandlerTypedef = packageApi.typeAliasDeclarations
          .singleWhere((element) => element.name == 'EventHandler');

      expect(eventHandlerTypedef.name, 'EventHandler');
      expect(eventHandlerTypedef.aliasedTypeName,
          'FutureOr<void> Function(Event, Emitter<State>)');
    });
  });
}
